#[non_exhaustive]pub struct ResourceRequest {Show 13 fields
pub url: String,
pub kind: ResourceKind,
pub loading_methods: LoadingMethods,
pub storage_policy: StoragePolicy,
pub priority: Priority,
pub usage: Usage,
pub tile: Option<TileRequest>,
pub data_range: Option<RangeInclusive<u64>>,
pub prior_modified: Option<SystemTime>,
pub prior_expires: Option<SystemTime>,
pub prior_etag: Option<String>,
pub prior_data: Option<Vec<u8>>,
pub minimum_update_interval: Duration,
}Expand description
Resource metadata passed to FileSource implementations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: StringResolved resource URL.
kind: ResourceKindResource kind.
loading_methods: LoadingMethodsAllowed loading methods.
storage_policy: StoragePolicyStorage policy requested by MapLibre Native.
priority: PriorityPriority requested by MapLibre Native.
usage: UsageWhether the request is made for online or offline use.
tile: Option<TileRequest>Tile metadata, present for tile requests.
data_range: Option<RangeInclusive<u64>>Requested inclusive byte range, present for partial reads.
prior_modified: Option<SystemTime>Previous Last-Modified value from cache, if known.
prior_expires: Option<SystemTime>Previous Expires value from cache, if known.
prior_etag: Option<String>Previous ETag, if known.
prior_data: Option<Vec<u8>>Previous body bytes from cache, if needed for a 304 response.
minimum_update_interval: DurationMinimum interval before refreshing this resource.